/**
 * 选择对话框
 * @param {Object} title 总标题
 * @param {Object} a //标题的选项  [{ title: "拍照"  }, { title: "从手机相册选择"  }]
 * @param {Object} number //相册时选择张数
 * @param {Object} Callback 回调函数 [{imagePath:'11',name:'123'}]
 */
function promptDialogue(title, number, callback) {
	function plusReady() {
		// 弹出系统选择按钮框
		plus.nativeUI.actionSheet({
			title: title,
			cancel: "取消",
			buttons: [{
				title: "拍照"
			}, {
				title: "从手机相册选择"
			}]
		}, function(e) {
			if (e.index == 0) {
				if (callback != undefined && callback != 'undefined') {
					callback(false, [], "取消选择！");
				}
			} else if (e.index == 1) {
				getImage1(callback);
			} else if (e.index == 2) {
				galleryImg(number, callback);
			}
		});
	}
	if (window.plus) {
		plusReady();
	} else {
		document.addEventListener("plusready", plusReady, false);
	}

}

/**
 * 拍照
 * @param {Object} Callback 回调函数 [{imagePath:'11',name:'123'}]
 */
function getImage(callback) {
	function plusReady() {
		plus.camera.getCamera().captureImage(function(path) {
			plus.io.resolveLocalFileSystemURL(path, function(entry) {
				startPrompt('请稍等正在处理...');
				var localUrl = entry.toLocalURL();
				if (localUrl != undefined && localUrl != '') {
					getBase64Image1('', localUrl, '', '', function(stry) {
						$.ajax({
							url: str + story_addPic,
							type: 'post',
							cache: false,
							async: true,
							data: {
								'bb': stry
							},
							dataType: 'json',
							success: function(data) {
								if (data.msg) {
									var data = {
										state: '成功',
										data: [{
											path: str + data.msg,
											name: "图片",
											type: "图片"
										}]
									}
									callback1(data);
								} else {
									var data = {
										state: '上传失败',
										data: []
									}
									callback1(data);
								}
							},
							error: function(x, y) {
								var data = {
									state: '上传失败服务器或网络未开！',
									data: []
								}
								callback1(data);
							}
						});
					});

				} else {
					var data = {
						state: '拍照失败',
						data: []
					}
					callback1(data);

				}

			}, function(err) {
				console.error("拍照失败：" + err.message);
				var data = {
					state: '拍照失败' + err.message,
					data: []
				}
				callback1(data);
			}, {
				index: 1
			});
		});

	}

	if (window.plus) {
		plusReady();
	} else {
		document.addEventListener('plusready', plusReady, false);
	}

	//回调函数
	function callback1(data) {
		if (callback && $.type(callback) === "function") {
			callback(data);
		}
	}

}

/**
 * 拍照
 * @param {Object} Callback 回调函数 [{imagePath:'11',name:'123'}]
 */
function getImage1(callback) {
	function plusReady() {
		plus.camera.getCamera().captureImage(function(path) {
			plus.io.resolveLocalFileSystemURL(path, function(entry) {
				var localUrl = entry.toLocalURL();
				if (localUrl != undefined && localUrl != '') {
					var pathArrt = path.split('/');
					var name = pathArrt[pathArrt.length - 1].split('.');
					fileInformation(path, function(is, fileInfor) {
						if (is == '成功') {
							var size = fileInfor.size / (1024 * 1024);
							if (size > 10) {
								callback1('', '拍照失败，您的图片大于10M。如拍照的原因请联系管理人员！');
								return;
							}
							callback1(true, [{
								path: localUrl,
								url: localUrl,
								name: name[0],
								type: name[1]
							}], '拍照成功！');
						} else {
							callback1('', fileInfor);
						}

					});
				} else {
					callback1(false, [], '拍照失败！');
				}
			}, function(err) {
				callback1(false, [], "拍照失败：" + err.message);
			}, {
				index: 1
			});
		});

	}

	if (window.plus) {
		plusReady();
	} else {
		document.addEventListener('plusready', plusReady, false);
	}

	//回调函数
	function callback1(is, data, msg) {
		if (callback && $.type(callback) === "function") {
			callback(is, data, msg);
		}
	}

}

/**
 * * 相册选择
 * @param {Object} number 张数  number = 0时为 无数张 number = 1时 为单张
 * @param {Object} Callback 回调函数 [{imagePath:'11',name:'123'}]
 */
function galleryImg(number, callback) {
	function plusReady() {
		var multiple = true;
		if (number == 0) {
			number = Infinity;
		} else if (number == 1) {
			multiple = false;
		}
		plus.gallery.pick(function(e) {
			var data = {
				state: '成功',
				data: []
			}
			if (number != 1) {
				var indexLengt = e.files.length;
				var index = 0;
				for (var i in e.files) {
					var pathArrt = e.files[i].split('/');
					var name = pathArrt[pathArrt.length - 1].split('.');
					fileInformation(e.files[i], function(is, fileInfor, Map) {
						index++;
						if (is == '成功') {
							var size = fileInfor.size / (1024 * 1024);
							if (size <= 10) {
								data.data.push(Map);
							}
						}
						if (index >= indexLengt) {
							if (data.data.length > 0) {
								callback1(true, data.data, '从相册选择成功！');
							} else {
								callback1(false, data.data, '从相册选择失败，有大于10的图片！');
							}
						}

					}, {
						path: e.files[i],
						url: e.files[i],
						name: name[0],
						type: name[1]
					});


				}
			} else {
				var pathArrt = e.split('/');
				var name = pathArrt[pathArrt.length - 1].split('.');
				fileInformation(e, function(is, fileInfor, Map) {
					if (is == '成功') {
						var size = fileInfor.size / (1024 * 1024);
						if (size <= 10) {
							data.data.push(Map);
						} 
					}
					if (data.data.length > 0) {
                        callback1(true, data.data, '从相册选择成功！');
					} else {
						callback1(false, data.data, '从相册选择失败，有大于10的图片！');
					}
				}, {
					path: e,
					url: e,
					name: name[0],
					type: name[1]
				});
			}

		}, function(e) {
			var data = {
				state: '取消选择图片',
				data: []
			}
			callback1(false, data.data, '取消选择图片');
		}, {
			filter: "image",
			multiple: multiple,
			maximum: number,
			system: false
		});

	}

	if (window.plus) {
		plusReady();
	} else {
		document.addEventListener('plusready', plusReady, false);
	}

	//回调函数
	function callback1(is, data, msg) {
		if (callback && $.type(callback) === "function") {
			callback(is, data, msg);
		}
	}
}

/**
 * 图片转码
 * @param {Object} img 图片对象
 * @param {Object} path 图片路径 （当图片路径为空时 已 img 对象为转码对象）
 * @param {Object} width 需要转码的 宽度 （可传空 ）
 * @param {Object} height 需要转码的 高度 （可传空 ）
 * @param {Object} callback 回调函数 返回 转码字符串 
 */
function getBase64Image1(img, path, width1, height1, callback) {
	var image = img;
	if (img == undefined || img == '') {
		image = new Image();
		image.src = path;
	}
	if (width1 != '' && height1 != '') {
		image.width = width;
		image.height = height;
	}

	image.onload = function() {
		var canvas = document.createElement("canvas");
		canvas.width = 500;
		canvas.height = 700;
		var ctx = canvas.getContext("2d");
		ctx.drawImage(image, 0, 0, 500, 700);
		var ext = image.src.substring(image.src.lastIndexOf(".") + 1).toLowerCase();
		var dataURL = canvas.toDataURL(ext, 1 || 0.5); //"image/png" + 
		callback1(dataURL);
		//dataURL.replace("data:image/png;base64,", "")
	}
	//回调函数
	function callback1(data) {
		if (callback && $.type(callback) === "function") {
			callback(data);
		}
	}
}

/**
 * 转码Base64
 * @param {Object} data 路径数组
 */
function transcodingBase64(data, callback) {
	var t = 0;
	var dataArray = [];
	for (var i = 0; i < data.length; i++) {
		getBase64Image1('', data[i].path, '', '', function(String) {
			t++;
			dataArray.push(String);
			if (t == data.length) {
				callback1(dataArray);
			}
		});
	}

	//回调函数
	function callback1(data) {
		if (callback && $.type(callback) === "function") {
			callback(data);
		}
	}
}

/**
 * 获取文件的信息 如 名字 路径 时间 类型等
 * @param {Object} path 文件的路径
 * @param {Object} callback 回调函数 第一个参数返回成功和失败两种结果，第二个参数 成功时返回文件的信息实体类，失败时返回失败的原因字符串
 */
function fileInformation(path, callback, Map) {
	if (window.plus) {
		onPlusReady();
	} else {
		document.addEventListener('plusready', onPlusReady(), false);
	}

	function onPlusReady() {
		plus.io.resolveLocalFileSystemURL(path, function(entry) {
			// 可通过entry对象操作test.html文件 
			entry.file(function(file) {
				callback1("成功", file);
			});
		}, function(e) {
			callback1("失败", e.message);
		});
	}

	//回调函数
	function callback1(string, data) {
		if (callback && $.type(callback) === "function") {
			callback(string, data, Map);
		}
	}
}

/**
 * 图片转码
 * @param {Object} img 图片对象
 * @param {Object} path 图片路径 （当图片路径为空时 已 img 对象为转码对象）
 * @param {Object} width 需要转码的 宽度 （可传空 ）
 * @param {Object} height 需要转码的 高度 （可传空 ）
 * @param {Object} callback 回调函数 返回 转码字符串 
 */
function getBase64Image2(path, callback) {
	if (window.plus) {
		onPlusReady();
	} else {
		document.addEventListener('plusready', onPlusReady(), false);
	}

	function onPlusReady() {
		if (path == undefined || path == 'undefined' || path == '') {
			callback1('');
			return;
		}
		fileInformation(path, function(is, fileInfor) {

			if (is == '成功') {
				var size = fileInfor.size / (1024 * 1024);
				if (size > 10) {
					callback1('', '转码失败，您的图片大于10M。如拍照的原因请联系管理人员！');
					return;
				}
				var fileReader = new plus.io.FileReader;
				fileReader.readAsDataURL(path);
				fileReader.onloadend = function(evt) {
					if (evt.target.result == undefined || evt.target.result == 'undefined' || evt.target.result == '') {
						callback1('', '转码失败！');
					} else {
						callback1(evt.target.result, '转码成功！');
					}
				}
			} else {
				callback1('', fileInfor);
			}

		});
	}
	//回调函数
	function callback1(data, msg) {
		if (callback && $.type(callback) === "function") {
			callback(data, msg);
		}
	}
}



/**
 * 本地路径转换成 file 文件上传
 * @param {Object} url 本地路径
 * @param {Object} callback(true/false,file文件对象,提示)
 */
function urlToFile(url,callback) {  
	var file;
	try{
		url = plus.io.convertLocalFileSystemURL(url);
		var nameArray = url != undefined && url != 'undefined'&& url != '' ? url.split('/'):[];
		var fileName = ""; 
		if(nameArray.length > 0 ){
			 fileName =nameArray[nameArray.length - 1];
			
		}else{
			if(callback != undefined && callback != 'undefined' && Object.prototype.toString.call(callback) == '[object Function]'){
				callback(false,'','路径不存在！');
			}
			return;
		}
		
		var fileReader = new plus.io.FileReader;
		fileReader.readAsDataURL(url);
		fileReader.onloadend = function(evt) {
			var dataurl = evt.target.result;
			var arr = dataurl.split(','), mime = arr[0].match(/:(.*?);/)[1],
			    bstr = atob(arr[1]), n = bstr.length, u8arr = new Uint8Array(n);
			while(n--){
			    u8arr[n] = bstr.charCodeAt(n);
			}
			if(callback != undefined && callback != 'undefined' && Object.prototype.toString.call(callback) == '[object Function]'){
				callback(true,new File([u8arr], fileName, {type:mime}),'转换file成功！');
			}
		};
	}catch(e){
		//TODO handle the exception
		if(callback != undefined && callback != 'undefined' && Object.prototype.toString.call(callback) == '[object Function]'){
			callback(false,'','解析出错！');
		}
		
	}
	
}