/**
 * 检查是否为空值
 * @param {Object} object 检查的对象 
 * @param {Object} sign 标志 
 * 返回：{type:type,value:value,isCorrect:isCorrect,remarks}  ： 
   type：当前传入数据的类型， 
   value 返回当前值或判断为false时返回常用值，
   isCorrect：（true/false）是否是对应的值 ，
   remarks（备注）：如数组长度不为0等,不等于空字符串（正常是true/false）
 * 1.当  sign == '' || sign == '1' || sign == '0'  时直接判断是否为空
   2. 当  sign == '2' ：判断是否为数组对象 remarks = true 为长度不等于0
   3. 当  sign == '3' ：判断是否是函数
   4. 当  sign == '4' ：判断是否为字符串的对象  isEmptyType.remarks = true 为不为空字符串
   5. 当  sign == '5' ：判断是否为数字
   6. 当  sign == '6' ：判断是否为判断类型
   7. 当  sign == '7' ：判断是否为对象
 */
var isEmptyType = function(objec, sign) {
	var typeObjec = {};
	typeObjec.type = objec != undefined && objec != 'undefined' ? Object.prototype.toString.call(objec) : '未知'; //类型
	typeObjec.value = objec != undefined && objec != 'undefined' ? objec : ""; //最终的值
	typeObjec.isCorrect = objec != undefined && objec != 'undefined' ? true : false; //是否是判断的值
	typeObjec.remarks = false; //备注值（如数组长度不为0等,不等于空字符串）
	switch(sign) {
		case 2:
		case '2':
			typeObjec.remarks = false; //备注值（如数组长度不为0等,不等于空字符串）
			//判断是否是长度不为0的数组
			if(objec != undefined && objec != 'undefined' && Object.prototype.toString.call(objec) == '[object Array]') {
				typeObjec.value = objec; //最终的值
				typeObjec.isCorrect = true; //是否是判断的值
				if(objec.length != 0) {
					typeObjec.remarks = true; //备注值（如数组长度不为0等）
				}
			} else {
				typeObjec.value = []; //最终的值
				typeObjec.isCorrect = false; //是否是判断的值
			}
			break;
		case 3:
		case '3':
			//判断是否是函数
			if(objec != undefined && objec != 'undefined' && Object.prototype.toString.call(objec) == '[object Function]') {
				typeObjec.value = objec; //最终的值
				typeObjec.isCorrect = true; //是否是判断的值
			} else {
				typeObjec.value = function() {}; //最终的值
				typeObjec.isCorrect = false; //是否是判断的值
			}
			break;
		case 4:
		case '4':
			typeObjec.remarks = false; //备注值（如数组长度不为0等,不等于空字符串）
			//判断是否为字符串的对象
			if(objec != undefined && objec != 'undefined' && Object.prototype.toString.call(objec) == '[object String]') {
				typeObjec.value = objec; //最终的值
				typeObjec.isCorrect = true; //是否是判断的值
				if(objec != '') {
					typeObjec.remarks = true; //备注值（如数组长度不为0等,为空字符串）
				}
			} else {
				typeObjec.value = ""; //最终的值
				typeObjec.isCorrect = false; //是否是判断的值
			}
			break;
		case 5:
		case '5':
			objec = Number(objec);
			var objecString = "" + objec;
			//判断是否为数字
			if(objec != undefined && objec != 'undefined' && Object.prototype.toString.call(objec) == '[object Number]' &&
				objecString != NaN && objecString != 'NaN') {

				typeObjec.value = objec; //最终的值
				typeObjec.isCorrect = true; //是否是判断的值
			} else {

				typeObjec.value = 0; //最终的值
				typeObjec.isCorrect = false; //是否是判断的值
			}
			break;
		case 6:
		case '6':
			//判断是否为判断类型
			if(objec != undefined && objec != 'undefined' && (Object.prototype.toString.call(objec) == '[object Boolean]' ||
					objec == 'true' || objec == 'false')) {
				typeObjec.value = true; //最终的值
				typeObjec.isCorrect = true; //是否是判断的值
				if(objec == 'false' || objec == false) {
					typeObjec.value = false; //最终的值
				}
			} else {
				typeObjec.value = ""; //最终的值
				typeObjec.isCorrect = false; //是否是判断的值
			}
			break;

		case 7:
		case '7':
			//判断是否为对象类型
			if(objec != undefined && objec != 'undefined' && Object.prototype.toString.call(objec) == '[object Object]') {
				typeObjec.value = objec; //最终的值
				typeObjec.isCorrect = true; //是否是判断的值
			} else {
				typeObjec.value = {}; //最终的值
				typeObjec.isCorrect = false; //是否是判断的值
			}
			break;

	}
	return typeObjec;
}

/**
 * 提示对话框
 * @param {Object} str 提示内容
 */
function Msg(str) {
	if(str == undefined || str == 'undefined' || str == '') {
		return;
	}

	var tString = '<div class="tipDisappearBoxLayout">' +
		'<img class="tipDisappearBoximg" src="../../../js/public/layer_mobile/need/tishi.png" />' +
		'<span class="tipDisappearBoxName" >' + str + '</span>' +
		'</div>';

	layer.open({
		content: str,
		skin: 'msg',
		time: 2 //2秒后自动关闭
	});
}
/**
 * 提交等待框
 * @param {Object} str 提示内容
 */
function Msg_wait(str) {
	localStorage.tyLayout = undefined;
	// H5 plus事件处理
	function plusReady() {
		// 弹出系统等待对话框
		plus.nativeUI.showWaiting(str);
	}
	if(window.plus) {
		plusReady();
	} else {
		document.addEventListener("plusready", plusReady, false);
	}

	/*if(localStorage.tyLayout != undefined && localStorage.tyLayout != 'undefined') {
		layer.close(localStorage.tyLayout);
	}
     if(str == undefined || str == 'undefined' || str == '') {
		localStorage.tyLayout = layer.open({
			type: 2,
			shadeClose: false,
		});
	} else {
		localStorage.tyLayout = layer.open({ 
			type: 2,
			content: str,
			shadeClose: false,
		});
	}*/

}

/**
 * 关闭提交等待框
 * @param {Object} str 提示内容
 */
function Msg_waitClose() {
	function plusReady() {
		// 弹出系统等待对话框
		plus.nativeUI.closeWaiting();

	}
	if(window.plus) {
		plusReady();
	} else {
		document.addEventListener("plusready", plusReady, false);
	}

	/*if(localStorage.tyLayout != undefined && localStorage.tyLayout != 'undefined') {
		
		layer.close(localStorage.tyLayout);
	}*/
}

/**
 * 存储数据
 * @param {Object} name key键
 * @param {Object} vur 存入的值
 */
function setlocalStorage(name, vur) {
	if(isEmptyType(vur, '2').isCorrect || isEmptyType(vur, '7').isCorrect) {
		localStorage.setItem(name, JSON.stringify(vur));
	} else {
		localStorage.setItem(name, vur);
	}

}

/**
 * 获取存储的数据
 * @param {Object} name key键
 * @param {Object} vur 获取失败后，需要返回的值
 */
function getlocalStorage(name, vur) {
	var rData = localStorage.getItem(name);
	if(rData == undefined || rData == 'undefined') {
		return vur;
	} else {
		try {
			rData = JSON.parse(rData);
		} catch(e) {
			console.log('保存')
		}
		return rData;
	}
}
/**
 * 获取网址传入的参数
 */
function GetRequest(callback) {
	var url = location.search; //获取url中"?"符后的字串   
	var versionIndex = 0;
	var theRequest = new Object();
	if(url.indexOf("?") != -1) {
		var str1 = url.substr(1);
		var strs = str1.split("&");
		for(var i = 0; i < strs.length; i++) {
			versionIndex++;
			theRequest[strs[i].split("=")[0]] = unescape(decodeURI(strs[i].split("=")[1]));
		}
	}
	if(callback != undefined && callback != 'undefined') {
		callback(theRequest, versionIndex);
	}
	return theRequest;
}

/**
 * 图片加载失败时加载错误的图片
 * @param {Object} a自己
 * @param {Object} url 展示的图片
 */
function whenError(a, url) {
	a.onerror = null;
	if(a.src != url) {
		a.src = url;
	} else {
		a.src = '../../../imgs/touxaing.png';
	}
}
/**
 * 图片加载失败时加载错误的图片
 * @param {Object} a自己
 * @param {Object} url 展示的图片
 */
function whenError1(a, url) {
	console.log('url = ' + url)
	a.onerror = null;
	if(a.src != url) {
		a.src = url;
	} else {
		a.src = '../../../imgs/touxaing.png';
	}
}

/**
 * 筛选字段（只要一出现都会进入）
 * primaryString：要筛选的字符串
 * searchString：要搜索的字符串
 */
function screenField(primaryString, searchString) {
	if(isEmptyType(primaryString, '4').value == '') {
		return '';
	}
	if(isEmptyType(searchString, '4').value == '') {
		return isEmptyType(primaryString, '4').value;
	}
	var primaryArray = primaryString.split('');
	var searchArray = searchString.split('');
	var primaryIndexArray = []; //装着索引的数组
	for(var i = 0; i < searchArray.length; i++) {
		for(var j = 0; j < primaryArray.length; j++) {
			if(searchArray[i] == primaryArray[j]) {
				primaryIndexArray.push(j);
			}
		}
	}

	var primaryIndexString = "";
	if(primaryIndexArray.length > 0) {
		primaryIndexString = ',' + primaryIndexArray.join(',') + ','; //abcde 
	}

	var lastString = ''; //最后字符串
	for(var i = 0; i < primaryArray.length; i++) {
		if(primaryIndexString.indexOf(',' + i + ',') > -1) {
			lastString += '<span>';
		}
		lastString += primaryArray[i];
		if(primaryIndexString.indexOf(',' + i + ',') > -1) {
			lastString += '</span>';
		}
	}

	return lastString;

}
/**
 * 筛选字段
 * primaryString：要筛选的字符串
 * searchString：要搜索的字符串
 */
function screenFieldComplete(primaryString, searchString) {
	if(isEmptyType(primaryString, '4').value == '') {
		return '';
	}
	if(isEmptyType(searchString, '4').value == '') {
		return isEmptyType(primaryString, '4').value;
	}
	var primaryArray = primaryString.split('');
	var searchArray = searchString.split('');
	var primaryIndexArray = []; //装着索引的数组
	var transitionIndexArray = []; //过渡索引的数组
	var transitionIndex = 0;
	while(transitionIndex < primaryArray.length) {
		transitionIndexArray = []; //过渡索引的数组
		for(var i = 0; i < searchArray.length; i++) {
			for(var j = transitionIndex; j < primaryArray.length; j++) {
				if(searchArray[i] == primaryArray[j]) {
					transitionIndex = j;
					transitionIndexArray.push(j);
					break;
				}
			}
		}
		if(transitionIndexArray.length == searchArray.length) {
			primaryIndexArray = primaryIndexArray.concat(transitionIndexArray);
		} else {
			transitionIndex = primaryArray.length;
		}
	}

	var primaryIndexString = "";
	if(primaryIndexArray.length > 0) {
		primaryIndexString = ',' + primaryIndexArray.join(',') + ','; //abcde 
	}

	var lastString = ''; //最后字符串
	for(var i = 0; i < primaryArray.length; i++) {
		if(primaryIndexString.indexOf(',' + i + ',') > -1) {
			lastString += '<span>';
		}
		lastString += primaryArray[i];
		if(primaryIndexString.indexOf(',' + i + ',') > -1) {
			lastString += '</span>';
		}
	}

	return lastString;

}

/**
 * 获取一个随机数
 * @param {Object} n
 * @param {Object} m
 */
function rnd(n, m) {
	var random = Math.floor(Math.random() * (m - n + 1) + n);
	return random;
}
getRequest = GetRequest();
//静态数组资源
var imgsF = [
	'http://pic25.photophoto.cn/20121207/0033034026251400_b.jpg',
	'http://www.pptbz.com/pptpic/UploadFiles_6909/201203/2012031220134655.jpg',
	'http://www.pptbz.com/pptpic/UploadFiles_6909/201306/2013062320262198.jpg',
	'http://www.pptok.com/wp-content/uploads/2012/08/xunguang-4.jpg',
	'http://img17.3lian.com/d/file/201702/14/3d1d78481dbe5db4802f4b1eb548f365.jpg',
	'http://pic5.photophoto.cn/20071027/0034034409450565_b.jpg',
	'http://pic30.photophoto.cn/20140115/0040039504628208_b.jpg',
	'http://pic9.photophoto.cn/20081229/0034034885643767_b.jpg',
	'http://pic6.photophoto.cn/20080219/0034034467797362_b.jpg',
	'http://pic5.photophoto.cn/20071228/0034034901778224_b.jpg',
	'http://pic5.photophoto.cn/20071219/0034034800188062_b.jpg',
	'http://pic25.photophoto.cn/20121128/0034034441708087_b.jpg',
	'http://pic12.photophoto.cn/20090731/0034034828392826_b.jpg',
	'http://pic24.photophoto.cn/20120903/0034034871284108_b.jpg',
	'http://imgsrc.baidu.com/imgad/pic/item/c8177f3e6709c93d45d74423953df8dcd1005438.jpg',
	'http://pic32.photophoto.cn/20140817/0034034463193076_b.jpg',
	'http://img1.juimg.com/140923/330672-14092321354485.jpg',
	'http://img2.3lian.com/2014/f4/125/d/132.jpg',
	'http://pic6.photophoto.cn/20080311/0034034854076462_b.jpg',
	'http://pic6.photophoto.cn/20080113/0034034824268875_b.jpg',
	'http://pic31.photophoto.cn/20140606/0020032871914282_b.jpg',
	'http://pic5.photophoto.cn/20071214/0033033955287991_b.jpg',
]
/**
 * 获取随机数组图片
 */
function getImgs() {
	return imgsF[rnd(0, imgsF.length - 1)];
}

/**
 * 获取文件的类型
 * @param {Object} path
 */
function fileType(path) {
	path = isEmptyType(path, '4').value;
	//0：pdf 1:word 2:电子表格 3：视频 4：图片
	var imgsString = ",jpg,png,tif,gif,.jpg,.png,.tif,.gif,"; //图片格式
	var voidString = ",mp4,3gp,avi,amv,.mp4,.3gp,.avi,.amv,"; //视频格式
	var autoString = ",mp3,wma,wav,ogg,.mp3,.wma,.wav,.ogg,mp3,.mp3,wma,.wma,wav,.wav,wav,.wav,amr,.amr,"; //音频文件
	var wordString = ",.doc,.docx,doc,docx,";
	var pdfString = ",.pdf,pdf,";
	var excelString = ",.xls,xlsx,";
	var pathArray = path.split('\.');
	if(pathArray.length > 1) {
		var typeO = ',' + pathArray[pathArray.length - 1] + ',';
		if(pdfString.indexOf(typeO) > -1) {
			return '0';
		} else if(wordString.indexOf(typeO) > -1) {
			return '1';
		} else if(excelString.indexOf(typeO) > -1) {
			return '2';
		} else if(voidString.indexOf(typeO) > -1) {
			return '3';
		} else if(imgsString.indexOf(typeO) > -1) {
			return '4';
		}
	} 
	return '5';
}
pauseFunction();//检测后台运行
/**
 * 检测后台运行
 */
function pauseFunction() { 
	mui.init();
	mui.plusReady(function() { 
		// 监听后台运行
		document.addEventListener('pause', function() {
			//console.log('后台运行...');
			setlocalStorage('isAutoShow',false);
		});
		// 监听前台运行
		document.addEventListener('resume', function() {
			//console.log('前台运行...');
			setlocalStorage('isAutoShow',true);
		});
	});

}


/**
 * [isMobile 判断平台]
 * @param test: false:iPhone    true:Android
 */ 
function ismobile(){
    var u = navigator.userAgent;
	var isAndroid = u.indexOf('Android') > -1 || u.indexOf('Adr') > -1; //android终端
	var isiOS = !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/); //ios终端
	if(isAndroid == true){
	     return 'isAndroid';
	}else if (isiOS == true){
		 return 'isiOS';
	}else{
		return undefined;
	}
};